# python-homewizard-kitchen
This package connects to the HomeWizard Kitchen's websocket to get & update a device status.
This project currently only implements the Kettle device.
Tested on a HomeWizard Kettle 1.4,HWK-KTL 1.07

## Installation
```
pip install homewizard-kitchen
```

## Usage
See [example.py](https://github.com/lesleyxyz/python-homewizard-kitchen/blob/main/example.py)

Afterwards you can use the Kettle model to update & retrieve data.